[−][src]Struct vectrix::Matrix
Represents a matrix with constant M rows and constant N columns.
The underlying data is represented as an array and is always stored in column-major order.
See the crate root for usage examples.
Implementations
impl<T> Matrix<T, 1_usize, N>[src]
impl<T> Matrix<T, 1_usize, N>[src]
impl<T> Matrix<T, 1_usize, N>[src]
impl<T> Matrix<T, 1_usize, N>[src]
pub const fn new(x: T, y: T, z: T, w: T) -> Self[src]
Creates a new vector from the given components.
impl<T> Matrix<T, 1_usize, N>[src]
pub const fn new(x: T, y: T, z: T, w: T, a: T) -> Self[src]
Creates a new vector from the given components.
impl<T> Matrix<T, 1_usize, N>[src]
pub const fn new(x: T, y: T, z: T, w: T, a: T, b: T) -> Self[src]
Creates a new vector from the given components.
impl<T> Matrix<T, M, 1_usize>[src]
impl<T> Matrix<T, M, 1_usize>[src]
impl<T> Matrix<T, M, 1_usize>[src]
pub const fn new(x: T, y: T, z: T, w: T) -> Self[src]
Creates a new vector from the given components.
impl<T> Matrix<T, M, 1_usize>[src]
pub const fn new(x: T, y: T, z: T, w: T, a: T) -> Self[src]
Creates a new vector from the given components.
impl<T> Matrix<T, M, 1_usize>[src]
pub const fn new(x: T, y: T, z: T, w: T, a: T, b: T) -> Self[src]
Creates a new vector from the given components.
impl<T, const M: usize, const N: usize> Matrix<T, M, N>[src]
#[must_use]pub fn zero() -> Self where
T: Copy + Zero, [src]
T: Copy + Zero,
Returns a zero vector.
pub fn as_slice(&self) -> &[T]ⓘ[src]
Views the underlying data as a contiguous slice.
pub fn as_mut_slice(&mut self) -> &mut [T]ⓘ[src]
Views the underlying data as a contiguous mutable slice.
pub fn iter(&self) -> Iter<'_, T>ⓘ[src]
Returns an iterator over the underlying data.
pub fn iter_mut(&mut self) -> IterMut<'_, T>ⓘ[src]
Returns an iterator over the data that allows modifying each value.
pub fn abs(self) -> Self where
T: Copy + Default + Abs, [src]
T: Copy + Default + Abs,
Returns the absolute value of the matrix.
pub fn l1_norm(&self) -> T where
T: Copy + Ord + Abs + Zero + Sum<T>, [src]
T: Copy + Ord + Abs + Zero + Sum<T>,
Returns the L1 norm of the matrix.
Also known as Manhattan Distance or Taxicab norm. L1 Norm is the sum of the magnitudes of the vectors in a space.
Note: if the matrix is a row vector this method might not do what you what you expect. For example:
let row_vector = matrix![1, 2, 3]; assert_eq!(row_vector.l1_norm(), 3); let column_vector = matrix![1; 2; 3]; assert_eq!(column_vector.l1_norm(), 6);